#!/bin/bash

# When executing the contents of a prehook or posthook directive, as
# defined below, tea4cups makes the following environment variables
# available to your own commands :
#
#      TEAPRINTERNAME : The print queue name.
#      TEADIRECTORY : Tea4CUPS output directory.
#      TEADATAFILE : Full name of Tea4CUPS work file (in $TEADIRECTORY).
#      TEAJOBSIZE : Job's size in bytes.
#      TEAMD5SUM : MD5 sum of the job's datas.
#      TEACLIENTHOST : Client's hostname or IP address.
#      TEAJOBID : Job's Id.
#      TEAUSERNAME : Name of the user who launched the print job.
#      TEATITLE : Job's title.
#      TEACOPIES : Number of copies requested.
#      TEAOPTIONS : Options of the print job.
#      TEAINPUTFILE : Job's data file or empty when job read from stdin.
#      TEABILLING : Job's billing code (lp -o job-billing=SomeCode file.ps)
#      TEACONTROLFILE : Job's IPP message file (usually /var/spool/cups/c?????)
#
# Your own commands will mostly be interested in TEADATAFILE which is
# the name of the file from which your commands may extract the final
# job's datas. Don't rely on TEAINPUTFILE, use TEADATAFILE instead
# since the first one may be empty depending on your printer driver.

# Our printers are e.g. Dell3110cn HPLaserJet4100tn OkiC9650 OKIC7500

case $TEAUSERNAME in
	# in alphabetical order
	adm)            lp -d HPLaserJet4100tn 	-t "$TEATITLE" "$TEADATAFILE";; # Kristian's Windows account on z091020
	anonymous)	;;
	bobergkr)       lp -d JAG-Dell3110cn 	-t "$TEATITLE" "$TEADATAFILE";; # Jubilaeumsaustellung on terminal server
	helga)          lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # Kristian's Windows account on z091020
	hennigjx)       lp -d JAG-Dell3110cn 	-t "$TEATITLE" "$TEADATAFILE";; # Jubilaeumsaustellung on terminal server
	herbstro2)	lp -d Silver 		-t "$TEATITLE" "$TEADATAFILE";; # Roland
	hoketill1)      lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # Till Hoke
	koschmid1)      lp -d HPLaserJet4100tn 	-t "$TEATITLE" "$TEADATAFILE";; # Daniel Koschmider
	koschmid2)      lp -d HPLaserJet4100tn 	-t "$TEATITLE" "$TEADATAFILE";; # Daniel Koschmider
	langekri9)      lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # Kristian's Win terminal server account
	schulung01)     lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # Till Hoke's Schulungs-Account
	postestp)       lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # ?
	root)           ;;
	schromar9)      lp -d Dell3110cn 	-t "$TEATITLE" "$TEADATAFILE";; # Martin Schroeder
	wendrotl)       lp -d OkiC9650 		-t "$TEATITLE" "$TEADATAFILE";; # Lothar Wendroth on terminal server
	wendrotl1)      lp -d Dell3110cn 	-t "$TEATITLE" "$TEADATAFILE";; # Lothar Wendroth on terminal server
	*)              echo "E [$(date)] [JobID $TEAJOBID] sort2printer: User $TEAUSERNAME does not exist." >> \
				/var/log/cups/sort2printer.log;;
esac
